/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>

uint32 interruptCnt = 1u;

/*Logical Size of Em_EEPROM*/
#define LOGICAL_EEPROM_START    16u
#define ILO_FREQ                32000                       /* Hz */

/* EEPROM storage in work flash, this is defined in Em_EEPROM.c*/
#if defined (__ICCARM__)
#pragma data_alignment = CY_FLASH_SIZEOF_ROW
const uint8_t Em_EEPROM_em_EepromStorage[Em_EEPROM_PHYSICAL_SIZE] = {0u};
#else
const uint8_t Em_EEPROM_em_EepromStorage[Em_EEPROM_PHYSICAL_SIZE]
__ALIGNED(CY_FLASH_SIZEOF_ROW) = {0u};
#endif /* defined (__ICCARM__) */

void InitWatchdog(uint16 sleep_interval);
CY_ISR(WDT_ISRHandler);
cy_en_em_eeprom_status_t eepromReturnValue;
uint8_t eepromPosition[1] = {0x00u};
uint8_t eepromStartArray[16] = {0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu,0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu, 0xFFu,0xFFu, 0xFFu};


//Global ADC variables
int16 adcResult1;
int16 adcResult2;
volatile unsigned char adc_low1; // lower byte of lmp measurement
volatile unsigned char adc_high1; // upper byte of lmp measurement
volatile unsigned char adc_low2; // lower byte of lmp measurement
volatile unsigned char adc_high2; // upper byte of lmp measurement    



int main(void)
{
    __enable_irq();
    eepromReturnValue = Em_EEPROM_Init((uint32_t)Em_EEPROM_em_EepromStorage);
    /* initialize watchdog */
    InitWatchdog(1000);
    /* connect ISR routine to Watchdog interrupt */
    WDT_ISR_StartEx(WDT_ISRHandler);
    /* set the highest priority to make ISR is executed in all condition */
    WDT_ISR_SetPriority(0);
    /* enable global interrupt */
    CyGlobalIntEnable; 
    SensorADC_Start();
    SensorADC_StartConvert();
    // eepromReturnValue = Em_EEPROM_Write(LOGICAL_EEPROM_START, eepromPosition, 0x00u); //Uncomment to clear EEProm Position
    eepromReturnValue = Em_EEPROM_Write(0x00u, eepromStartArray, 0x10u);
    eepromReturnValue = Em_EEPROM_Read(LOGICAL_EEPROM_START, eepromPosition, 0x01u);

    
    for(;;)
    {
    
        /* clear watchdog counter before deep sleep */
        CySysWdtResetCounters(CY_SYS_WDT_COUNTER0_RESET);
        /* reset watchdog counter requires several LFCLK cycles to take effect */
        CyDelayUs(150); 
        /* go to deep sleep mode */
        CySysPmDeepSleep();
        if (interruptCnt > 120) {
            eepromReturnValue = Em_EEPROM_Read(LOGICAL_EEPROM_START, eepromPosition, 0x01u);
            if (eepromPosition[0] <= 160) {
            	SensorADC_Start();                                          /* Start up the ADC */
		        SensorADC_StartConvert();                                   /* Start ADC conversion */
		        SensorADC_IsEndConversion(SensorADC_WAIT_FOR_RESULT);             /* Wait for result to complete */
		        SensorADC_StopConvert();                                    /* Stop ADC conversions  */
		        SensorADC_Stop();    
                adcResult1 = SensorADC_GetResult16(0x00u);
                adc_low1 = (adcResult1) & 0xFF;
                adc_high1 =  (adcResult1 >> 8) & 0xFF;
                adcResult2 = SensorADC_GetResult16(0x01u);
                adc_low2 = (adcResult2) & 0xFF;
                adc_high2 =  (adcResult2 >> 8) & 0xFF;
                uint8_t dataArray[5] = {adc_low1, adc_high1, adc_low2, adc_high2, 0xFF};          
                eepromReturnValue = Em_EEPROM_Write(LOGICAL_EEPROM_START + 1 + 5*eepromPosition[0], dataArray, 0x05u);
                eepromPosition[0]++;
                eepromReturnValue = Em_EEPROM_Write(LOGICAL_EEPROM_START, eepromPosition, 0x01u);            
            }
        }
    //        uint8_t eepromArray[256];
    //        eepromReturnValue = Em_EEPROM_Read(LOGICAL_EEPROM_START, eepromArray, 0x100u);
    //        eepromReturnValue = Em_EEPROM_Read(LOGICAL_EEPROM_START, eepromArray, 0x100u);
    }
}

CY_ISR(WDT_ISRHandler)
{
    interruptCnt++;
    if (interruptCnt > 31) { //CHANGE THE NUMBER IN THIS COMPARISON (num) TO CHANGE TIME BETWEEN MEASUREMENTS.
           interruptCnt = 1u; //GAP = 1 * (num-1) seconds += 60 percent
    }
    /* clear interrupt flag to enable next interrupt */
    CySysWdtClearInterrupt(CY_SYS_WDT_COUNTER0_INT); 
}

void InitWatchdog(uint16 sleep_interval)
{
    /*==============================================================================*/
    /* configure counter 0 for wakeup interrupt                                     */
    /*==============================================================================*/
    /* Counter 0 of Watchdog time generates peridically interrupt to wakeup system */
    CySysWdtWriteMode(CY_SYS_WDT_COUNTER0, CY_SYS_WDT_MODE_INT);
    /* Set interval as desired value */
	CySysWdtWriteMatch(CY_SYS_WDT_COUNTER0, ((uint32)(sleep_interval * ILO_FREQ) / 1000));
    /* clear counter on match event */
	CySysWdtWriteClearOnMatch(CY_SYS_WDT_COUNTER0, 1u);
    
    /*==============================================================================*/
    /* enable watchdog                                                              */
    /*==============================================================================*/
    /* enable the counter 0 */
    CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);
    /* check if counter 0 is enabled, otherwise keep looping here */
    while(!CySysWdtReadEnabledStatus(CY_SYS_WDT_COUNTER0));
}

/* [] END OF FILE */
